################################################################################################
# Load a custom menu on startup and register interest in any other events we are interested in
################################################################################################
import hiero
import shot_manager_xlsx
import shot_manager_hiero
import custom_widgets
from PySide2 import QtWidgets

def __create_track_from_xlsx():
    """Get the xlsx file from the user and create a track from it's data"""
    db_handle = shot_manager_hiero.get_db_handle(silent=True)
    if db_handle:
        shot_manager_hiero.create_track_from_data(db_handle.read_shot_data('shots'))

def add_menu(event):
    """Add a custom menu and action to the main toolbar"""
    menu_bar = hiero.ui.menuBar()
    menu = menu_bar.addMenu('Shot Manager')
    menu.addAction(QtWidgets.QAction('Import From Spreadsheet', menu, triggered=__create_track_from_xlsx))

def add_database_panel(event):
    """Add a custom panel to the location for the xlsx file"""
    # store the instance of the widet so we can reference it at any point during a Hiero session
    hiero.ui.database_settings_panel = custom_widgets.DatabaseSettingsPanel()

    # add the instance to Hiero's windows manager so it can be docked etc like the default panels
    wm = hiero.ui.windowManager()
    wm.addWindow(hiero.ui.database_settings_panel, wm.kApplicationSection)
    

# add Shot Manager menu to main toolbar on Hiero start up
hiero.core.events.registerInterest('kStartup', add_menu)

# add Database Settings panel on Hiero start up
hiero.core.events.registerInterest('kStartup', add_database_panel)

# make sub menu add itself to the context menu when it's shown (but only in the timeline)
sub_menu = custom_widgets.MenuWidget('Shot Manager')
hiero.core.events.registerInterest('kShowContextMenu/kTimeline', sub_menu.add_to_menu)
