import hiero
import send_for_review_exporter
from PySide2 import QtWidgets

class SubmitForClientReviewUI(hiero.exporters.FnTranscodeExporterUI.TranscodeExporterUI):
    """Provides an interface for the exporter to update the preset's properties(), which in turn is used by the processor"""
    def __init__(self, preset):
        super(SubmitForClientReviewUI, self).__init__(preset)
        #hiero.exporters.FnTranscodeExporterUI.TranscodeExporterUI.__init__(self, preset)
        self._displayName = "Submit For Client Review"
        # link UI to processor
        self._taskType = send_for_review_exporter.SubmitForClientReviewExporter
    
    def populateUI(self, widget, exportTemplate):
        """Build the UI for tis exporter.
        widget is the parent widget that holds the UI."""

        # add default UI
        super(SubmitForClientReviewUI, self).populateUI(widget, exportTemplate)
        
        # add custom widgets and load their values from properties dict
        self.publishWidget = QtWidgets.QCheckBox()       
        self.publishWidget.setChecked(self._preset.properties()['submitThumbnails'])
        
        # add the custom widgets to the base porcessor's form layout
        self._formLayout.insertRow(0, 'Submit Thumbnails', self.publishWidget)

        # connext any signals that need connecting to make the custom widgets functional
        self.connectSignalsAndSlots()

    def connectSignalsAndSlots(self):
        self.publishWidget.stateChanged.connect(self._publishWidgetChanged)

    def _publishWidgetChanged(self, state):
        '''Save widget values in preset's properties()'''
        self._preset.properties()['submitThumbnails'] = bool(state)

hiero.ui.taskUIRegistry.registerTaskUI(send_for_review_exporter.SubmitForClientReviewPreset, SubmitForClientReviewUI)
